Filter Distances by Element Symbols
filter_by_elements.RdRemoves any distance pair where at least one of the atoms corresponds to a specified list of element symbols.
See also
Other property calculators:
calculate_angles(),
calculate_distances(),
calculate_neighbor_counts(),
calculate_weighted_neighbor_counts(),
filter_atoms_by_symbol(),
filter_by_wyckoff_symbol()
Examples
dists <- data.table::data.table(Atom1 = "Si1_1_0_0", Atom2 = "O1_1_0_0", Distance = 1.6)
ac <- data.table::data.table(Label = c("Si1", "O1"))
filter_by_elements(dists, ac, elements_to_exclude = "O")
#> Empty data.table (0 rows and 3 cols): Atom1,Atom2,Distance