Calculate Coordination Numbers
calculate_neighbor_counts.RdCounts the number of nearest neighbors for each central atom based on a table of bonded pairs.
See also
Other property calculators:
calculate_angles(),
calculate_distances(),
calculate_weighted_neighbor_counts(),
filter_atoms_by_symbol(),
filter_by_elements(),
filter_by_wyckoff_symbol()
Examples
bp <- data.table::data.table(Atom1 = c("Si1", "Si1", "O1"),
Atom2 = c("O1", "O2", "Si1"))
calculate_neighbor_counts(bp)
#> Atom CoordinationNumber
#> <char> <int>
#> 1: Si1 2
#> 2: O1 1